var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Api } from "../../Api";
import { ChannelsGroupsService } from "./ChannelsGroupsService";
import { DevicesService } from "./DevicesService";
export var AddNewGroupErrorCode;
(function (AddNewGroupErrorCode) {
    AddNewGroupErrorCode["Success"] = "Success";
    AddNewGroupErrorCode["NoPermissions"] = "NoPermissions";
    AddNewGroupErrorCode["NameToShort"] = "NameToShort";
    AddNewGroupErrorCode["NameAlreadyExists"] = "NameAlreadyExists";
    AddNewGroupErrorCode["OtherError"] = "OtherError";
    AddNewGroupErrorCode["UnknownError"] = "UnknownError";
})(AddNewGroupErrorCode || (AddNewGroupErrorCode = {}));
export class ChannelsGroup {
    constructor() {
        this._guid = "";
        this._name = "";
        this._position = 0;
        this._objectsOrder = {};
        if (ChannelsGroup._devicesService == null)
            ChannelsGroup._devicesService = Api.Get(DevicesService.ServiceName);
    }
    GetDevicesChannelsInGroupAsync(withScenes = false) {
        return __awaiter(this, void 0, void 0, function* () {
            let channels = [];
            for (let device of yield Api.Get(DevicesService.ServiceName).GetDevicesAsync(withScenes)) {
                for (let channel of device.Channels.where(channel => channel.ChannelGroups.any(group => group === this._guid))) {
                    channels.push(channel);
                }
            }
            let sortedChannels = [];
            if (this._objectsOrder !== undefined && this._objectsOrder !== null && Object.entries(this._objectsOrder).length > 0) {
                const sortedKeys = Object.keys(this._objectsOrder)
                    .map(Number) // convert strings to numbers
                    .sort((a, b) => a - b); // sort by numeric values
                for (let s of sortedKeys) {
                    const ch = channels.firstOrDefault(a => a.ChannelId === this._objectsOrder[s]);
                    if (ch !== null)
                        sortedChannels.push(ch);
                }
                channels.forEach(a => {
                    if (!sortedChannels.any(b => b.ChannelId === a.ChannelId))
                        sortedChannels.push(a);
                });
                return sortedChannels;
            }
            return channels;
        });
    }
    get Guid() {
        return this._guid;
    }
    set Guid(value) {
        this._guid = value;
    }
    get Name() {
        return this._name;
    }
    set Name(value) {
        this._name = value;
    }
    get OrderPosition() {
        return this._position;
    }
    set OrderPosition(value) {
        this._position = value;
    }
    get ObjectsOrder() {
        return this._objectsOrder;
    }
    set ObjectsOrder(value) {
        this._objectsOrder = value;
    }
    ChangeNameAsync(name) {
        return Api.Get(ChannelsGroupsService.ServiceName).ChangeGroupNameAsync(this, name);
    }
}
//# sourceMappingURL=IChannelsGroupsService.js.map